@@ -11,6 +11,8 @@ from sklearn.model_selection import TimeSeriesSplit
 import pandas as pd # type: ignore
 from pandas.core.generic import NDFrame # type:ignore
 import pdb
+import dask
+import dask.dataframe as dd
 
 import matplotlib.pyplot as plt # type: ignore
 
@@ -22,7 +24,7 @@ from fbprophet.plot import plot_cross_validation_metric
 from .build_base import BuildBase
 
 # helper functions
-from ..utils import print_dynamic_rmse, quick_ts_plot
+from ..utils import print_dynamic_rmse, quick_ts_plot, print_ts_model_stats
 from ..utils.logging import SuppressStdoutStderr
 
 #### Suppress INFO messages from FB Prophet!
@@ -154,19 +156,19 @@ class BuildProphet(BuildBase):
         else:
             print('      No seasonality assumed since seasonality flag is set to False')
 
-        with SuppressStdoutStderr():
-            self.model.fit(dft)
-            self.train_df = copy.deepcopy(dft)
 
-        print("  End of Prophet Fit")
+        if type(dft) == dask.dataframe.core.DataFrame:
+            num_obs = dft.shape[0].compute()
+        else:
+            num_obs = dft.shape[0]
 
-        num_obs = dft.shape[0]
+        ### Creating a new way to skip cross validation when trying to run auto-ts multiple times. ###
+        if cv == 0:
+            cv_in = 0
+        else:
+            cv_in = copy.deepcopy(cv)
         NFOLDS = self.get_num_folds_from_cv(cv)
 
-        if self.verbose >= 2:
-            print(f"NumObs: {num_obs}")
-            print(f"NFOLDS: {NFOLDS}")
-
         #########################################################################################
         # NOTE: This change to the FB recommendation will cause the cv folds from facebook to
         # be incompatible with the folds from the other models (in terms of periods of evaluation
@@ -206,79 +208,99 @@ class BuildProphet(BuildBase):
         ###########################################################################################
         #cv = GapWalkForward(n_splits=NFOLDS, gap_size=0, test_size=self.forecast_period)
         max_trainsize = len(dft) - self.forecast_period
-        cv = TimeSeriesSplit(n_splits=NFOLDS, max_train_size = max_trainsize)
+        try:
+            cv = TimeSeriesSplit(n_splits=NFOLDS, test_size=self.forecast_period) ### this works only sklearn v 0.0.24]
+        except:
+            cv = TimeSeriesSplit(n_splits=NFOLDS, max_train_size = max_trainsize)
         y_preds = pd.DataFrame()
         print('Max. iterations using expanding window cross validation = %d' %NFOLDS)
         start_time = time.time()
         rmse_folds = []
         norm_rmse_folds = []
-        y_trues = pd.DataFrame()
-        for fold_number, (train_index, test_index) in enumerate(cv.split(dft)):
-            train_fold = dft.iloc[train_index]
-            test_fold = dft.iloc[test_index]
-            horizon = len(test_fold)
-            print(f"\nFold Number: {fold_number+1} --> Train Shape: {train_fold.shape[0]} Test Shape: {test_fold.shape[0]}")
+        forecast_df_folds = []
 
-            #########################################
-            #### Define the model with fold data ####
-            #########################################
+        concatenated = pd.DataFrame()
+        extra_concatenated = pd.DataFrame()
 
+        if type(dft) == dask.dataframe.core.DataFrame:
+            dft = dft.head(len(dft)) ### this converts dask into a pandas dataframe
+
+        if  cv_in == 0:
+            print('Skipping cross validation steps since cross_validation = %s' %cv_in)
             model = Prophet(growth="linear")
-
-            ############################################
-            #### Fit the model with train_fold data ####
-            ############################################
-
             kwargs = {'iter':1e2} ## this limits iterations and hence speeds up prophet
-            model.fit(train_fold, **kwargs)
+        else:
+            for fold_number, (train_index, test_index) in enumerate(cv.split(dft)):
+                dftx = dft.head(len(train_index)+len(test_index))
+                train_fold = dftx.head(len(train_index)) ## now train will be the first segment of dftx
+                test_fold = dftx.tail(len(test_index)) ### now test will be right after train in dftx
 
-            #################################################
-            #### Predict using model with test_fold data ####
-            #################################################
+                horizon = len(test_fold)
+                print(f"\nFold Number: {fold_number+1} --> Train Shape: {train_fold.shape[0]} Test Shape: {test_fold.shape[0]}")
 
-            future_period = model.make_future_dataframe(freq=time_int, periods=horizon)
-            forecast_df = model.predict(future_period)
-            ### Now compare the actuals with predictions ######
-            y_pred = forecast_df['yhat'][-horizon:]
-            if fold_number == 0:
-                y_preds = copy.deepcopy(y_pred)
-            else:
-                y_preds = y_preds.append(y_pred)
-            rmse_fold, rmse_norm = print_dynamic_rmse(test_fold[actual],y_pred,test_fold[actual])
-            print('Cross Validation window: %d completed' %(fold_number+1,))
-            rmse_folds.append(rmse_fold)
-            norm_rmse_folds.append(rmse_norm)
+                #########################################
+                #### Define the model with fold data ####
+                #########################################
 
-        ######################################################
-        ### This is where you consolidate the CV results #####
-        ######################################################
-        fig = model.plot(forecast_df)
-        rmse_mean = np.mean(rmse_folds)
-        print('Average CV RMSE over %d windows (macro) = %0.5f' %(fold_number+1,rmse_mean))
-        y_trues = dft[-y_preds.shape[0]:][actual]
-        cv_micro = np.sqrt(mean_squared_error(y_trues.values,
-                                              y_preds.values))
-        print('Average CV RMSE of all predictions (micro) = %0.5f' %cv_micro)
+                model = Prophet(growth="linear")
 
-        try:
-            if self.verbose >= 2:
-                quick_ts_plot(y_trues, y_preds)
-            else:
-                pass
-        except:
-            print('Error: Not able to plot Prophet CV results')
+                ############################################
+                #### Fit the model with train_fold data ####
+                ############################################
 
-        forecast_df_folds = copy.deepcopy(y_preds)
-        print("  End of Prophet Cross Validation")
-        print('Time Taken = %0.0f seconds' %((time.time()-start_time)))
+                kwargs = {'iter':1e2} ## this limits iterations and hence speeds up prophet
+                model.fit(train_fold, **kwargs)
 
-        if self.verbose >= 1:
-            print("Prophet CV DataFrame")
-            #print(performance_metrics(df_cv).head())
-        if self.verbose >= 2:
-            print("Prophet plotting CV Metrics")
-            #_ = plot_cross_validation_metric(df_cv, metric=self.scoring)
-            #plt.show()
+                #################################################
+                #### Predict using model with test_fold data ####
+                #################################################
+
+                future_period = model.make_future_dataframe(freq=time_int, periods=horizon)
+                forecast_df = model.predict(future_period)
+                ### Now compare the actuals with predictions ######
+
+                y_pred = forecast_df['yhat'][-horizon:]
+
+                concatenated = pd.DataFrame(np.c_[test_fold[actual].values,
+                            y_pred.values], columns=['original', 'predicted'],index=test_fold.index)
+
+                if fold_number == 0:
+                    extra_concatenated = copy.deepcopy(concatenated)
+                else:
+                    extra_concatenated = extra_concatenated.append(concatenated)
+
+                rmse_fold, rmse_norm = print_dynamic_rmse(concatenated['original'].values, concatenated['predicted'].values,
+                                            concatenated['original'].values)
+
+                print('Cross Validation window: %d completed' %(fold_number+1,))
+                rmse_folds.append(rmse_fold)
+                norm_rmse_folds.append(rmse_norm)
+
+            ######################################################
+            ### This is where you consolidate the CV results #####
+            ######################################################
+            fig = model.plot(forecast_df)
+            #rmse_mean = np.mean(rmse_folds)
+            #print('Average CV RMSE over %d windows (macro) = %0.5f' %(fold_number+1,rmse_mean))
+
+
+            #cv_micro = np.sqrt(mean_squared_error(y_trues.values, y_preds.values))
+            #print('Average CV RMSE of all predictions (micro) = %0.5f' %cv_micro)
+
+            try:
+                print_ts_model_stats(extra_concatenated['original'], extra_concatenated['predicted'], "Prophet")
+            except:
+                print('Error: Not able to plot Prophet CV results')
+
+            forecast_df_folds = extra_concatenated['predicted'].values
+            #print("  End of Prophet Cross Validation")
+            print('Time Taken = %0.0f seconds' %((time.time()-start_time)))
+
+        #### Now you need to fit Prophet on the whole train data set ##########
+        dftx = dft.head(len(dft))
+        self.model = model
+        self.model.fit(dftx, **kwargs)
+        print("  End of Prophet Fit")
 
         #num_obs_folds = df_cv.groupby('cutoff')['ds'].count()
 
@@ -320,10 +342,6 @@ class BuildProphet(BuildBase):
         #     print('Error in FB Prophet components forecast. Continuing...')
 
         #rmse, norm_rmse = print_dynamic_rmse(dfa['y'], dfa['yhat'], dfa['y'])
-        print('---------------------------')
-        print('Final Prophet CV results:')
-        print('---------------------------')
-        rmse, norm_rmse = print_dynamic_rmse(y_trues, y_preds, y_trues)
 
         #return self.model, forecast, rmse, norm_rmse
         return self.model, forecast_df_folds, rmse_folds, norm_rmse_folds
